@@ -70,26 +70,17 @@
 #' @examples
 #' \dontrun{
 #' ## Example 1: Independent SI Model
-#' # Initialize network and set network model parameters
+#' # Network model estimation
 #' nw <- network.initialize(n = 100, bipartite = 50, directed = FALSE)
-#' formation <- ~ edges
+#' formation <- ~edges
 #' target.stats <- 50
-#' dissolution <- ~ offset(edges)
-#' duration <- 20
-#' coef.diss <- dissolution_coefs(dissolution, duration)
+#' coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
+#' est1 <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 #'
-#' # Estimate the ERGM models (see help for netest)
-#' # Skipping model diagnostics for this, but one should always run these
-#' est1 <- netest(nw, formation, dissolution,
-#'                target.stats, coef.diss, verbose = FALSE)
-#'
-#' # Parameters, initial conditions, and controls for model
+#' # Epidemic model
 #' param <- param.net(inf.prob = 0.3, inf.prob.m2 = 0.15)
 #' init <- init.net(i.num = 10, i.num.m2 = 10)
-#' control <- control.net(type = "SI", nsteps = 100, nsims = 5,
-#'                        verbose.int = 0)
-#'
-#' # Run the model simulation
+#' control <- control.net(type = "SI", nsteps = 100, nsims = 5, verbose.int = 0)
 #' mod1 <- netsim(est1, param, init, control)
 #'
 #' # Print, plot, and summarize the results
@@ -99,11 +90,11 @@
 #'
 #' ## Example 2: Dependent SIR Model
 #' # Recalculate dissolution coefficient with death rate
-#' coef.diss <- dissolution_coefs(dissolution, duration, d.rate = 0.0021)
+#' coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20,
+#'                                d.rate = 0.0021)
 #'
 #' # Reestimate the model with new coefficient
-#' est2 <- netest(nw, formation, dissolution,
-#'                target.stats, coef.diss, verbose = FALSE)
+#' est2 <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 #'
 #' # Reset parameters to include demographic rates
 #' param <- param.net(inf.prob = 0.3, inf.prob.m2 = 0.15,
@@ -125,11 +116,7 @@
 #' summary(mod2, at = 100)
 #' }
 #'
-netsim <- function(x,
-                   param,
-                   init,
-                   control
-                   ) {
+netsim <- function(x, param, init, control) {
 
   crosscheck.net(x, param, init, control)
   if (!is.null(control[["verbose.FUN"]])) {
@@ -196,7 +183,10 @@ netsim <- function(x,
 #'
 #' @details
 #' This function is deprecated and has been replaced by the \code{netsim_par}
-#' function in the \code{EpiModel.hpc package}.
+#' function in the \code{EpiModelHPC package}.
+#'
+#' @seealso
+#' The EpiModelHPC repository may be found at \url{http://github.com/statnet/EpiModelHPC}.
 #'
 #' @keywords internal
 #' @export
@@ -204,7 +194,7 @@ netsim <- function(x,
 netsim_parallel <- function(x, param, init, control, merge = TRUE) {
 
   stop("EpiModel::netsim_parallel has been deprecated.",
-       "Use EpiModel.hpc::netsim_par instead.", .call = FALSE)
+       "Use EpiModelHPC::netsim_par instead.", .call = FALSE)
 
   return(all)
 }
